#------------------------ global elm.rc file ------------------
#
# this expects any global aliases in /var/lib/elm/aliases.text
#
# this is the unqualified hostname
#
hostname = darkstar
#
# this is the local domain
#
hostdomain = .frop.org
#
# this is the fully qualified hostname
#
hostfullname = darkstar.frop.org
